Synthetic Data
==============

Cedalion provides tools for generating synthetic data for testing and
development purposes. This includes functions for generating synthetic
hemodynamic response functions (HRFs) and synthetic motion artifacts.

.. autosummary::
   :toctree: _autosummary_synth
   :recursive:

   cedalion.sim.synthetic_artifact
   cedalion.sim.synthetic_hrf


Examples
--------

.. nbgallery::
   :glob:

   ../examples/augmentation/*